@@ -2,10 +2,11 @@
 #define STRICT_R_HEADERS
 
 #include <Rinternals.h>
-#include <libssh/libssh.h>
-#include <libssh/callbacks.h>
 #include <stdlib.h>
 #include <string.h>
+#include <libssh/libssh.h>
+#include <libssh/callbacks.h>
+
 
 /* Debian ships with libssh 0.8.0 which has a bug so it looks like 0.7.0 */
 #if defined(LIBSSH_VERSION_INT) && (LIBSSH_VERSION_INT >= SSH_VERSION_INT(0,8,0) || LIBSSH_VERSION_INT == SSH_VERSION_INT(0,7,0))
@@ -18,3 +19,8 @@
 ssh_session ssh_ptr_get(SEXP ptr);
 int pending_interrupt();
 void assert_channel(int rc, const char * what, ssh_channel channel);
+
+/* Workaround from libcurl: https://github.com/curl/curl/pull/9383/files */
+#if defined(__GNUC__) && (LIBSSH_VERSION_MINOR >= 10) || (LIBSSH_VERSION_MAJOR > 0)
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
